extensions [import-a fetch]

globals [dt
  school
  housepatch
  shop
  library
  hospital
  playground
  num-students
  num-houses
  max-infected
  transmissibility
  infection-radius
  R0
  R0-avg
  length-of-infection
  total-vaccinated
  social-distancing?
]

breed[houses house]


breed [schoolso schoolo]
breed [libraryso libraryo]
breed [shops shopnasium]
breed [hosps hosp]
breed [students student]


students-own[
  target
  infected?
  exposed?
  immune?
  recovered?
  hospitalized?
  vaccinated?

  infectedcount
  count-down
  infectcount-down

  dorm
  contacts-per-tick
  masked?
]

to setup
  clear-all

  fetch-image

	setup-circle
  set num-students 100
  set num-houses 25
  set total-vaccinated percent-vaccinated * num-students / 100
  set social-distancing? false
  ;Sets colored areas where students will move around
  ask patches with [pxcor > 62.0 and pxcor < 74.5 and pycor < 32.0 and pycor > 20.0] [set pcolor [168 0 132]] ;shop

  ;; houses
;  ask patches with [pxcor > 50.0 and pxcor < 74.5 and pycor < 48.0 and pycor > 35.0] [set pcolor brown + 3]
  ask patches with [pxcor > 47.0 and pxcor < 58.0 and pycor > 43.0 and pycor <  47.0] [set pcolor brown + 3]
  ask patches with [pxcor > 60.0 and pxcor < 66.0 and pycor > 44.0 and pycor < 47.0] [set pcolor brown + 3]
  ask patches with [pxcor > 69 and pxcor < 75.5 and pycor > 42.0 and pycor < 46.0] [set pcolor brown + 3]
  ask patches with [pxcor > 53.0 and pxcor < 58.5 and pycor > 38.0 and pycor < 42.0] [set pcolor brown + 3]
  ask patches with [pxcor > 60.0 and pxcor < 66.0 and pycor > 39.0 and pycor < 42.0] [set pcolor brown + 3]
  ask patches with [pxcor > 54.0 and pxcor < 60.0 and pycor > 35.0 and pycor < 38.0] [set pcolor brown + 3]
  ask patches with [pxcor > 63.0 and pxcor < 68.0 and pycor > 36.0 and pycor < 39.0] [set pcolor brown + 3]

  ask patches with [pxcor > 3.0 and pxcor < 28.0 and pycor < 45.0 and pycor > 35.0] [set pcolor [255 170 0]] ;school
	ask patches with [pxcor > 5.0 and pxcor < 26.0 and pycor < 27.0 and pycor > 18.0] [set pcolor [0 112 255]] ;library
	ask patches with [pxcor > 50.0 and pxcor < 74.5 and pycor < 13.0 and pycor > .5] [set pcolor [200 191 231]] ;hospital
  ask patches with [pxcor > 30.0 and pxcor < 43.0 and pycor < 35.0 and pycor > 26.0] [set pcolor [38 115 0]] ;playground
	
  set school patches with [pcolor = [255 170 0]]
  set playground patches with [pcolor = [38 115 0]]
  set shop patches with [pcolor = [168 0 132]]
  set library patches with [pcolor = [0 112 255]]
  set housepatch  patches with [pcolor = brown + 3]
  set hospital patches with [pcolor = [200 191 231]]

  ; Assign values for infection parameters
  set transmissibility 0.00375 * 2
  set infection-radius 1 / sqrt(200) * sqrt(num-students)
  set length-of-infection 336
  set R0-avg 0


  populate-students
  setup-vaccinated
  setup-infected

  reset-ticks
end


to fetch-image
  clear-all
  fetch:url-async (word "https://i.imgur.com/jD2DVZO.png") import-a:drawing
end


to setup-infected
  let initially-infected ceiling (percent-initially-infected *  (count students with [vaccinated? = false]) / 100)
  ask n-of initially-infected students with [vaccinated? = false] [
    set exposed? false
    set infected? true
    set color [255 0 0]
  ]
end

to setup-vaccinated
  ask n-of total-vaccinated students [
   set exposed? false
   set infected? false
   set immune? true
   set vaccinated? true
    set color [255 255 0]
  ]
end

to setup-circle
  set-default-shape turtles "circle"
  ;; turtles should be evenly spaced around the circle
  crt 1 [make-sun-moon-start]
end


to make-sun-moon-start
  set shape "moon"
  set color white
  ;set size 4.0
  set size 7
  set xcor 66
  set ycor 70
end

to make-sun-moon
  if ticks = 28[
  set shape "sun"
  set xcor 7
  set ycor 70
  set color yellow
  set size 7
  ask patches with [pxcor > -1.0 and pxcor < 80 and pycor < 80 and pycor > 50] [set pcolor [138 215 255]] ;SKY-day
  ]
  if  ticks = 76 [
    set shape "moon"
    set color white
    set xcor 66
    set ycor 70
    set size 7
    ask patches with [pxcor > -1.0 and pxcor < 80 and pycor < 80 and pycor > 50] [set pcolor [0 0 0]] ;SKY-night
  ]

  if (ticks - 28) mod 96 = 0 and ticks != 0 [
    set shape "sun"
    set xcor 7
    set ycor 70
    set color yellow
    set size 7
    ask patches with [pxcor > -1.0 and pxcor < 80 and pycor < 80 and pycor > 50] [set pcolor [138 215 255]] ;SKY-day
  ]

  if (ticks - 76) mod 96 = 0 and ticks != 0 [
    set shape "moon"
    set color white
    set xcor 66
    set ycor 70
    set size 7
    ask patches with [pxcor > -1.0 and pxcor < 80 and pycor < 80 and pycor > 50] [set pcolor [0 0 0]] ;SKY-night
  ]

end


to make-top
  set shape "circle"
  set color white
  set size .3
  set xcor 66.0
  set ycor 71.5

end


to make-center
  set size .35
  set shape "circle"
  set color yellow
  set xcor 66
  set ycor 68

end


to go

   ask turtle 0
   [
     make-sun-moon
   ]

  if stay-at-home? [
    ask students [move-to one-of housepatch]
  ]
  if quarantine? [
    ask students with [infected?][move-to one-of housepatch]
  ]



	;;stop if everyone or no one is infected
  if (count students with [infected? and not hospitalized?] = 0)
  or (count students with [infected?] = num-students)
  [stop]

  infect-susceptibles

  ask students with [exposed? and count-down > 0][
  	set count-down count-down - 1
  ]

  ask students with [exposed? and count-down <= 0][
    ifelse (random-float 1 < 0.03)[
     hospitalize
    ]
    [infect]

  ]

  ask students with [infected? and infectcount-down >= 0][
    if infectcount-down = 0[
      setupinfect-timer
    ]
    set infectcount-down infectcount-down - 1
  ]

  ask students with [infected? and hospitalized? = false and infectcount-down <= 0][
    recover
  ]

  move-students

  student-schedule


  calculate-max-infected


  tick


end



to setupexpose-timer
  set count-down 288
end

to setupinfect-timer
  set infectcount-down 1440
end

to infect-susceptibles

  ask students with [not immune? and not infected? and not exposed? and not recovered?] [
    let infected-neighbors-no-masks (count other students with [infected? and not masked?] in-radius infection-radius)
    let infected-neighbors-masked (count other students with [infected? and masked?] in-radius infection-radius)
    let effective-beta transmissibility

    if social-distancing? = false [set effective-beta 2 * transmissibility]
    if patch-here = playground  [set effective-beta 2 * effective-beta ]
    ;; Formula of transmissibility to avoid the probability exceeding 1
    if (random-float 1 <  (1 - ((1 - effective-beta) ^ (infected-neighbors-no-masks)) * ((1 - 0.2 * effective-beta) ^ (infected-neighbors-masked))))
    [

      expose

    ]
  ]
end



to expose
  setupexpose-timer
  set exposed? true
  set color [225 175 0]


end


to infect
    setupinfect-timer
    set exposed? false
    set infected? true
    set color [255 0 0]


end

to hospitalize
  set exposed? false
  set infected? true
  set hospitalized? true
  set color blue
  move-to one-of hospital
end

to recover
  set infected? false
  set recovered? true
  set immune? true
  set color gray
end


to student-schedule

 	let fourth-of-students floor num-students / 4
  let half-of-students floor num-students / 2


  if ticks mod 97 = 0 [
    ask students [
    	set masked? false
  	]
  ]

  if ticks mod 97 = 0 [
    ask n-of (floor %mask-compliance * num-students / 100) students [
      set masked? true
    ]
  ]

  ;;1 tick = 15min
  ;;4 ticks = 1hr
  ;;96 ticks = 1 day


  ;;8 am School
	if ticks = 32 or ((ticks - 32) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = false ][

      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
 				move-to one-of school
  		]
    ]
  ]

 if ticks = 32 or ((ticks - 32) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = true ][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false[
 				move-to one-of school
  		]
    ]
  ]

   if ticks = 48 or ((ticks - 48) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
 				move-to one-of school
  		]
    ]
  ]

  if ticks = 54 or ((ticks - 54) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
 				move-to one-of school
  		]
    ]
  ]

  if ticks = 54 or ((ticks - 54) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = true][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false[
 				move-to one-of school
  		]
    ]
  ]


  ;;2 pm activities
  if ticks = 56 or ((ticks - 56) mod 96 = 0 and ticks != 0)
	[
    let half (count students with [infected? = false]) / 2
    ask n-of half students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
         move-to one-of shop
    	]
    ]
    ask n-of half students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
         move-to one-of playground
    	]
    ]


  ]
  if ticks = 56 or ((ticks - 56) mod 96 = 0 and ticks != 0)
	[
    let half (count students with [infected? = true]) / 2
    ask n-of half students with [infected? = true][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false[
         move-to one-of shop
    	]
    ]

    ask n-of half students with [infected? = true][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false[
         move-to one-of playground
    	]
    ]


  ]


  ;;4 pm back home
  if ticks = 64 or ((ticks - 64) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
         move-to dorm
			]
    ]
  ]
  if ticks = 64 or ((ticks - 64) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = true][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false[
         move-to dorm
			]
    ]
  ]

  if ticks = 68 or ((ticks - 68) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
    		move-to one-of housepatch
			]
    ]
  ]
  if ticks = 68 or ((ticks - 68) mod 96 = 0 and ticks != 0)
  [
    ask students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false [
    		move-to one-of housepatch
			]
    ]
  ]

  if ticks = 70 or ((ticks - 70) mod 96 = 0 and ticks != 0)
  [
    let half (count students with [infected? = false]) / 2
    ask n-of half students with [infected? = false][
      if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
        move-to one-of library
    	]
    ]
  ]
  if ticks = 70 or ((ticks - 70) mod 96 = 0 and ticks != 0)
  [
    let half (count students with [infected? = true]) / 2
    ask n-of half students with [infected? = true][
      if stay-at-home? = false and hospitalized? = false and quarantine? = false [
        move-to one-of library
    	]
    ]
  ]

	if ticks = 78 or ((ticks - 78) mod 96 = 0 and ticks != 0)
  [
  ask students with [infected? = false][
		if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
        move-to dorm
			]
    ]
  ]
  if ticks = 78 or ((ticks - 78) mod 96 = 0 and ticks != 0)
  [
  ask students with [infected? = true][
		if stay-at-home? = false and hospitalized? = false and quarantine? = false [
        move-to dorm
			]
    ]
  ]

  if ticks = 81 or ((ticks - 81) mod 96 = 0 and ticks != 0)
  [
  ask students with [infected? = false][
		if stay-at-home? = false and hospitalized? = false and (quarantine? = false or infected? = false)[
        move-to dorm
			]
    ]
  ]
  if ticks = 81 or ((ticks - 81) mod 96 = 0 and ticks != 0)
  [
  ask students with [infected? = true][
		if stay-at-home? = false and hospitalized? = false and quarantine? = false [
        move-to dorm
			]
    ]
  ]


end


to move-students ;; Global procedure to move students
  ;; Procedue to make the students perform random walk
  ask students with [hospitalized? = false] [
    if quarantine? = false or infected? = false [
      let color-here [pcolor] of patch-here
      set target one-of patches in-cone 3 180 with [ pcolor = color-here]
      motion
      if pcolor != color-here [motion]]
  ]
end

to motion ;; Turtle procedure to perform random walk
  rt random 30 - 15
  if target != nobody [
    face target
    move-to target
  ]
  fd random 0.05
end

to populate-students ;; Procedure to create agents for students
  ask n-of num-students housepatch [ sprout-students 1]
  ask students [
    set size 1.0
    set shape "person"
    set color cyan
    set dorm patch-here
    set infected? false
    set immune? false
    set exposed? false
    set contacts-per-tick 0
    set masked? false
    set recovered? false
    set hospitalized? false
    set vaccinated? false
  ]
end

to calculate-max-infected
  let x (count students with [infected?])
  if x > max-infected
  [set max-infected x]
end
@#$#@#$#@
GRAPHICS-WINDOW
275
5
1147
878
-1
-1
11.38
1
10
1
1
1
0
0
0
1
0
75
0
75
0
0
1
ticks
30.0

BUTTON
50
235
220
268
Set Up (Click me first!)
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
50
275
219
308
Go! / Stop!
go\n
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
50
85
220
118
%Mask-Compliance
%Mask-Compliance
0
100
50.0
1
1
NIL
HORIZONTAL

SWITCH
50
155
220
188
stay-at-home?
stay-at-home?
1
1
-1000

SWITCH
50
190
220
223
quarantine?
quarantine?
1
1
-1000

PLOT
1161
10
1611
436
Evolution of Infection
Ticks 
Number of Students 
0.0
10.0
0.0
10.0
true
true
"set-plot-y-range 0 count turtles\nset-plot-x-range 0 100" ""
PENS
"Infected " 1.0 0 -5298144 true "" "plot (count students with [infected? = true])"
"Susceptible " 1.0 0 -13210332 true "" "plot (count students with [infected? = false and immune? = false and recovered? = false])"
"Exposed " 1.0 0 -4079321 true "" "plot (count students with [exposed? = true])"
"Recovered" 1.0 0 -7500403 true "" "plot (count students with [recovered? and immune?])"
"Hospitalized " 1.0 0 -14070903 true "" "plot (count students with [hospitalized?])"

MONITOR
1365
441
1526
486
Number of Infected
max-infected
2
1
11

SLIDER
50
50
220
83
percent-initially-Infected
percent-initially-Infected
1
50
5.0
1
1
NIL
HORIZONTAL

BUTTON
50
315
220
348
Reset to Defaults 
set %mask-compliance 50\nset stay-at-home? false\nset quarantine? false\nset percent-vaccinated 50\nset percent-initially-Infected 5
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
35
420
263
897
Clicking setup generates a population of students in this town. The model recreates the impact of the following policies to contain the spread of COVID-19:\n\n1. Stay-at-home: Students do not go to school or any of the other town facilities and must stay in their homes.\n\n2. Quarantine: The infected students isolate themselves in their homes and remain stationary.\n\n3. Mask compliance: The mask wearing resets at 00:00 hrs and only the selected percentage of students, chosen randomly, wear masks.\n\n4. Social distancing: The transmissibility of the virus is cut in half assuming people follow social-distancing guidelines\n\nThe simulation uses representative schedules and student activities. The slider for %playground-activities determines how many students engange in various activities that take place outside of school. The model sets transmissibility to a higher value in such scenarios because adherance to social-distancing and mask wearing is much more lax.\n\n(The purpose of this simulation is illustrative)
11
0.0
1

MONITOR
1189
442
1343
487
Number of Days Passed
ticks / 96
0
1
11

TEXTBOX
55
20
215
41
Set Conditions:
14
0.0
1

SLIDER
50
120
220
153
percent-vaccinated
percent-vaccinated
0
100
50.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This is an illustrative simulation of the spread of COVID-19 in a theoretical small town. Each agent in this simulation represents a student in the grades K-12 in this town. 
This model uses a generic student schedule on a given weekday. The students start at their homes, can go to the library, cafeteria, gym, and also particpate in recreational activities by going to the playgrounds. 

## HOW IT WORKS

The students each have homes, where their days both start and end. When a student becomes infected, they are able to infect other students near them. The students perform random walking when they are at a set area. 
The probability of a stuent becoming infected by another is reduced by 80% if the infected student is wearing a mask. 
The length of the infection for a student is set to a fixed number of 15 days. 
There are also stay at home and quarantine options that would change the schedule of the students and their mobility. 
In the case of stay at home, all students are to stay in their respective homes.
In the case of quarantine all the infected students stay put. 

## HOW TO USE IT
Clicking setup generates a population of students in the town. The current implementation includes two policies:

Stay-at-home: Students don’t go to school or any other town facilities and stay in their respective homes.
Quarantine: The infected students isolate themselves in their houses and remain stationary.
Initially infected: The number of students in the town who are already infected at the start of the simulation. 
Mask compliance: Only the selected percentage of students, chosen randomly, wear masks.
Social distancing: The transmissibility of the virus is cut in half assuming people follow social-distancing guidelines

The simulation uses a general schedule of students in a small town. 

## THINGS TO NOTICE

How different settings such as initially infected, social distancing, etc. can affetct the spread of the virus. 

## THINGS TO TRY

Switching the stay at home and quarantine options as the simulation is running to see the affect on the spread. 


## CREDITS AND REFERENCES
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

building institution
false
0
Rectangle -13345367 true false 30 90 225 210
Polygon -13345367 true false 30 90 120 45 225 90
Polygon -16777216 true false 225 210 285 180 285 75 225 90 225 210
Polygon -1 true false 120 45 195 45 285 75 225 90 120 45
Line -1 false 225 105 285 90
Rectangle -13791810 true false 15 105 45 120
Rectangle -16777216 true false 45 105 56 121
Rectangle -13345367 true false 15 90 195 105
Rectangle -16777216 true false 210 90 225 105
Line -16777216 false 15 90 210 90
Line -16777216 false 15 105 210 105
Rectangle -13791810 true false 62 106 92 121
Rectangle -13791810 true false 129 106 159 121
Rectangle -13791810 true false 179 106 209 121
Rectangle -13791810 true false 21 120 36 210
Rectangle -13791810 true false 68 120 83 210
Rectangle -16777216 true false 160 105 171 121
Rectangle -16777216 true false 93 106 104 122
Rectangle -16777216 true false 210 106 221 122
Rectangle -13791810 true false 135 120 150 210
Rectangle -13791810 true false 185 120 200 210
Rectangle -13791810 true false 15 195 45 210
Rectangle -13791810 true false 62 195 92 210
Rectangle -16777216 true false 37 121 45 194
Rectangle -16777216 true false 84 122 92 195
Rectangle -16777216 true false 151 121 159 194
Rectangle -16777216 true false 201 122 209 195
Rectangle -16777216 true false 46 194 57 210
Rectangle -16777216 true false 93 195 104 211
Rectangle -16777216 true false 160 195 171 211
Rectangle -16777216 true false 210 195 221 211
Rectangle -13791810 true false 129 195 159 210
Rectangle -13791810 true false 179 195 209 210
Rectangle -16777216 true false 108 165 123 210
Rectangle -13345367 true false 0 210 209 224
Polygon -16777216 true false 213 226
Polygon -16777216 true false 210 225 225 210 210 210 210 225
Line -16777216 false 0 215 209 215
Line -16777216 false 0 220 209 220
Line -1 false 210 105 225 105
Rectangle -1 false false 108 164 123 209
Line -16777216 false 21 121 39 121
Line -16777216 false 62 122 90 122
Line -16777216 false 128 121 156 121
Line -16777216 false 178 121 210 121
Line -16777216 false 179 195 211 195
Line -16777216 false 128 195 160 195
Line -16777216 false 62 195 94 195
Line -16777216 false 14 195 46 195
Circle -1 true false 106 63 21
Line -1 false 108 209 123 199
Line -16777216 false 138 121 138 194
Line -16777216 false 144 121 144 194
Line -16777216 false 188 121 188 194
Line -16777216 false 194 121 194 194
Line -16777216 false 71 122 71 195
Line -16777216 false 77 122 77 195
Line -16777216 false 24 121 24 194
Line -16777216 false 30 121 30 194
Rectangle -13791810 true false 98 155 123 163
Rectangle -16777216 true false 124 155 133 163

building institution-original
false
0
Rectangle -7500403 true true 0 60 300 270
Rectangle -16777216 true false 130 196 168 256
Rectangle -16777216 false false 0 255 300 270
Polygon -7500403 true true 0 60 150 15 300 60
Polygon -16777216 false false 0 60 150 15 300 60
Circle -1 true false 135 26 30
Circle -16777216 false false 135 25 30
Rectangle -16777216 false false 0 60 300 75
Rectangle -16777216 false false 218 75 255 90
Rectangle -16777216 false false 218 240 255 255
Rectangle -16777216 false false 224 90 249 240
Rectangle -16777216 false false 45 75 82 90
Rectangle -16777216 false false 45 240 82 255
Rectangle -16777216 false false 51 90 76 240
Rectangle -16777216 false false 90 240 127 255
Rectangle -16777216 false false 90 75 127 90
Rectangle -16777216 false false 96 90 121 240
Rectangle -16777216 false false 179 90 204 240
Rectangle -16777216 false false 173 75 210 90
Rectangle -16777216 false false 173 240 210 255
Rectangle -16777216 false false 269 90 294 240
Rectangle -16777216 false false 263 75 300 90
Rectangle -16777216 false false 263 240 300 255
Rectangle -16777216 false false 0 240 37 255
Rectangle -16777216 false false 6 90 31 240
Rectangle -16777216 false false 0 75 37 90
Line -16777216 false 112 260 184 260
Line -16777216 false 105 265 196 265

building store
false
0
Rectangle -7500403 true true 30 45 45 240
Rectangle -16777216 false false 30 45 45 165
Rectangle -7500403 true true 15 165 285 255
Rectangle -16777216 true false 120 195 180 255
Line -7500403 true 150 195 150 255
Rectangle -16777216 true false 30 180 105 240
Rectangle -16777216 true false 195 180 270 240
Line -16777216 false 0 165 300 165
Polygon -7500403 true true 0 165 45 135 60 90 240 90 255 135 300 165
Rectangle -7500403 true true 0 0 75 45
Rectangle -16777216 false false 0 0 75 45

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

cafeteria
true
0
Rectangle -16777216 true false 90 75 90 75
Rectangle -14835848 true false 30 105 210 195
Polygon -1 true false 30 30 90 15
Polygon -1 true false 29 30
Polygon -1 true false 209 107
Polygon -13840069 true false 210 105 270 75 90 75 150 105 210 105
Polygon -14835848 true false 30 105 30 30 150 105 30 105
Polygon -16777216 true false 270 75 270 195
Polygon -13840069 true false 31 30 90 19 202 74 149 106 31 31
Rectangle -14835848 true false 210 60 225 90
Polygon -16777216 true false 225 60 240 45 241 75 225 90 225 60
Polygon -13840069 true false 240 45 225 45 210 60 225 60 240 45
Polygon -16777216 true false 216 57 216 27 223 27 223 57 216 57
Polygon -16777216 true false 226 48 226 27 232 27 232 48 226 48
Line -16777216 false 202 75 150 105
Rectangle -16777216 true false 90 165 135 195
Rectangle -16777216 true false 150 165 180 180
Rectangle -16777216 true false 45 165 75 180
Rectangle -1 false false 45 165 75 180
Line -1 false 165 165 165 180
Line -1 false 60 165 60 180
Line -1 false 150 178 180 178
Line -1 false 45 178 75 178
Rectangle -1 false false 90 165 135 195
Line -1 false 112 166 112 195
Rectangle -1 false false 108 180 116 189
Polygon -16777216 true false 45 60
Polygon -16777216 true false 42 68 42 98 118 98 42 53 42 68
Polygon -1 false false 41 52 119 98 42 98 41 53
Line -1 false 58 63 58 98
Line -1 false 78 75 78 97
Rectangle -1 false false 150 165 181 180
Polygon -13840069 true false 92 149 77 164 138 164 152 149 92 149
Rectangle -16777216 true false 76 164 135 170
Rectangle -1 false false 76 164 136 171
Rectangle -13840069 true false 76 172 81 200
Rectangle -13840069 true false 130 172 135 200
Polygon -16777216 true false 210 105 270 75 270 165 210 195 210 105
Polygon -1 false false 225 165 225 180 240 165 240 150 225 165
Line -1 false 232 159 232 173
Line -1 false 226 176 240 162
Line -16777216 false 30 105 210 105

cafeteriaoriginal
true
0
Rectangle -14835848 true false 60 75 240 195
Rectangle -14835848 true false 45 60 255 75
Rectangle -16777216 true false 90 75 90 75
Rectangle -16777216 true false 120 150 180 195
Rectangle -1 false false 120 150 180 195
Line -1 false 150 150 150 195
Rectangle -1 false false 75 90 105 120
Rectangle -1 false false 195 90 225 120
Rectangle -1 false false 135 90 165 120
Rectangle -1 false false 75 135 105 165
Rectangle -1 false false 195 135 225 165
Rectangle -16777216 false false 60 75 240 195

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

gym
true
0
Rectangle -2064490 true false 30 105 270 210
Rectangle -16777216 true false 120 165 180 210
Rectangle -16777216 false false 30 105 270 210
Rectangle -1 false false 45 120 75 150
Rectangle -1 false false 90 120 120 150
Rectangle -1 false false 135 120 165 150
Rectangle -1 false false 180 120 210 150
Rectangle -1 false false 225 120 255 150
Rectangle -1 false false 210 165 240 195
Line -1 false 150 165 150 210
Rectangle -1 false false 60 165 90 195
Rectangle -2064490 true false 15 90 285 105
Rectangle -1 false false 120 165 180 210

hospital
true
0
Line -8630108 false 135 60 135 105
Rectangle -8630108 true false 45 105 255 210
Rectangle -8630108 true false 75 60 225 105
Rectangle -2674135 true false 120 75 180 90
Rectangle -2674135 true false 135 60 165 105
Rectangle -16777216 true false 120 165 180 210
Line -1 false 120 165 120 210
Line -1 false 120 165 180 165
Line -1 false 180 165 180 210
Line -1 false 150 165 150 210
Rectangle -1 false false 60 120 90 150
Rectangle -1 false false 105 120 135 150
Rectangle -1 false false 150 120 180 150
Rectangle -1 false false 195 120 225 150
Rectangle -1 false false 210 165 240 195
Rectangle -1 false false 60 165 90 195

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

house bungalow
false
0
Rectangle -7500403 true true 210 75 225 255
Rectangle -7500403 true true 90 135 210 255
Rectangle -16777216 true false 165 195 195 255
Line -16777216 false 210 135 210 255
Rectangle -16777216 true false 105 202 135 240
Polygon -7500403 true true 225 150 75 150 150 75
Line -16777216 false 75 150 225 150
Line -16777216 false 195 120 225 150
Polygon -16777216 false false 165 195 150 195 180 165 210 195
Rectangle -16777216 true false 135 105 165 135

house colonial
false
0
Rectangle -7500403 true true 270 75 285 255
Rectangle -7500403 true true 45 135 270 255
Rectangle -16777216 true false 124 195 187 256
Rectangle -16777216 true false 60 195 105 240
Rectangle -16777216 true false 60 150 105 180
Rectangle -16777216 true false 210 150 255 180
Line -16777216 false 270 135 270 255
Polygon -7500403 true true 30 135 285 135 240 90 75 90
Line -16777216 false 30 135 285 135
Line -16777216 false 255 105 285 135
Line -7500403 true 154 195 154 255
Rectangle -16777216 true false 210 195 255 240
Rectangle -16777216 true false 135 150 180 180

house efficiency
false
0
Rectangle -7500403 true true 180 90 195 195
Rectangle -7500403 true true 90 165 210 255
Rectangle -16777216 true false 165 195 195 255
Rectangle -16777216 true false 105 202 135 240
Polygon -7500403 true true 225 165 75 165 150 90
Line -16777216 false 75 165 225 165

house ranch
false
0
Rectangle -7500403 true true 270 120 285 255
Rectangle -7500403 true true 15 180 270 255
Polygon -7500403 true true 0 180 300 180 240 135 60 135 0 180
Rectangle -16777216 true false 120 195 180 255
Line -7500403 true 150 195 150 255
Rectangle -16777216 true false 45 195 105 240
Rectangle -16777216 true false 195 195 255 240
Line -7500403 true 75 195 75 240
Line -7500403 true 225 195 225 240
Line -16777216 false 270 180 270 255
Line -16777216 false 0 180 300 180

house two story
false
0
Polygon -7500403 true true 2 180 227 180 152 150 32 150
Rectangle -7500403 true true 270 75 285 255
Rectangle -7500403 true true 75 135 270 255
Rectangle -16777216 true false 124 195 187 256
Rectangle -16777216 true false 210 195 255 240
Rectangle -16777216 true false 90 150 135 180
Rectangle -16777216 true false 210 150 255 180
Line -16777216 false 270 135 270 255
Rectangle -7500403 true true 15 180 75 255
Polygon -7500403 true true 60 135 285 135 240 90 105 90
Line -16777216 false 75 135 75 180
Rectangle -16777216 true false 30 195 93 240
Line -16777216 false 60 135 285 135
Line -16777216 false 255 105 285 135
Line -16777216 false 0 180 75 180
Line -7500403 true 60 195 60 240
Line -7500403 true 154 195 154 255

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

moon
false
0
Polygon -7500403 true true 175 7 83 36 25 108 27 186 79 250 134 271 205 274 281 239 207 233 152 216 113 185 104 132 110 77 132 51

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Polygon -16777216 true false 180 60 255 150 225 195 165 120
Polygon -16777216 true false 105 90 105 195 75 285 90 300 135 300 150 255 165 300 210 300 225 285 195 195 195 90
Polygon -16777216 true false 105 75 45 150 75 195 150 120
Circle -16777216 true false 96 -9 108
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 105 90 60 150 75 180 135 105
Polygon -7500403 true true 105 90 120 195 90 285 105 285 135 285 150 225 165 285 195 285 210 285 180 195 195 90
Polygon -7500403 true true 195 90 240 150 225 180 165 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

road
true
0
Rectangle -7500403 true true 0 0 300 300
Rectangle -1 true false 0 75 300 225

road-middle
true
0
Rectangle -7500403 true true 0 0 300 300
Rectangle -10899396 true false 0 45 300 255

road2
true
0
Rectangle -7500403 true true 0 0 300 300

school
true
0
Polygon -16777216 true false 195 75 255 45 255 165 195 195 195 75
Rectangle -955883 true false 195 135 240 195
Polygon -1 true false 195 135 255 105 300 105 240 135 195 135
Polygon -955883 true false 195 75 240 135 195 135 195 75
Rectangle -955883 true false 15 75 195 195
Rectangle -16777216 true false 180 150 210 180
Rectangle -16777216 true false 135 150 165 180
Rectangle -16777216 true false 30 150 60 180
Rectangle -16777216 true false 180 105 210 135
Rectangle -16777216 true false 135 105 165 135
Rectangle -16777216 true false 75 105 120 135
Rectangle -16777216 true false 30 105 60 135
Polygon -955883 true false 30 75
Polygon -16777216 true false 210 195 270 165
Polygon -1184463 true false 270 60
Polygon -16777216 true false 210 75 240 45
Polygon -16777216 true false 255 45
Polygon -1 true false 255 45 60 45 15 75 195 75 255 45
Polygon -955883 true false 45 75 105 30 165 75 45 75
Polygon -1184463 true false 104 31
Polygon -1 true false 105 30 180 15 225 45 165 75 105 30
Polygon -16777216 true false 195 135 195 135 195 150 195 150
Polygon -1184463 true false 195 135
Polygon -16777216 true false 240 195 300 165 300 105 240 135 240 195
Polygon -1 true false 195 75 240 135 270 120 225 60 195 75
Line -16777216 false 195 75 255 45
Line -16777216 false 225 60 270 120
Line -16777216 false 225 45 165 75
Rectangle -16777216 true false 75 165 120 195
Rectangle -955883 true false 45 45 60 60
Polygon -1 true false 45 45 60 30 75 30 60 45 45 45
Polygon -16777216 true false 75 30 75 45 60 60 60 45 75 30
Rectangle -16777216 true false 51 32 58 41
Rectangle -1 false false 135 150 165 180
Rectangle -1 false false 180 150 210 180
Rectangle -1 false false 180 105 210 135
Rectangle -1 false false 135 105 165 135
Rectangle -1 false false 30 105 60 135
Rectangle -1 false false 75 105 120 135
Rectangle -1 false false 30 150 60 180
Polygon -1 false false 255 180 255 150 270 135 270 165 255 180
Line -1 false 45 105 45 135
Line -1 false 90 105 90 135
Line -1 false 105 105 105 135
Line -1 false 150 105 150 135
Line -1 false 195 105 195 135
Line -1 false 195 150 195 180
Line -1 false 150 150 150 180
Line -1 false 45 150 45 180
Rectangle -1 false false 75 165 120 195
Line -1 false 97 165 97 195
Rectangle -1 false false 94 178 100 189
Line -1 false 75 120 120 120
Line -1 false 30 120 60 120
Line -1 false 135 120 165 120
Line -1 false 180 120 210 120
Line -1 false 30 165 60 165
Line -1 false 135 165 165 165
Line -1 false 180 165 210 165
Line -1 false 263 142 263 172
Line -1 false 255 164 270 148

schooloriginal
true
0
Rectangle -955883 true false 45 90 255 210
Polygon -955883 true false 75 90 150 45 225 90
Rectangle -16777216 true false 120 150 180 210
Line -1 false 120 150 120 210
Line -1 false 120 150 180 150
Line -1 false 180 150 180 210
Line -1 false 150 150 150 210
Rectangle -1 false false 60 105 90 135
Rectangle -1 false false 105 105 135 135
Rectangle -1 false false 165 105 195 135
Rectangle -1 false false 210 105 240 135
Rectangle -1 false false 210 150 240 180
Rectangle -1 false false 60 150 90 180

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

sun
false
0
Circle -7500403 true true 75 75 150
Polygon -7500403 true true 300 150 240 120 240 180
Polygon -7500403 true true 150 0 120 60 180 60
Polygon -7500403 true true 150 300 120 240 180 240
Polygon -7500403 true true 0 150 60 120 60 180
Polygon -7500403 true true 60 195 105 240 45 255
Polygon -7500403 true true 60 105 105 60 45 45
Polygon -7500403 true true 195 60 240 105 255 45
Polygon -7500403 true true 240 195 195 240 255 255

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tile stones
false
0
Rectangle -14835848 true false 0 0 300 300
Polygon -7500403 true true 0 90 0 105
Polygon -16777216 true false 43 1 0 96
Polygon -13840069 true false 15 105 90 105
Polygon -13840069 true false 15 75 60 75 30 15 0 75 60 75
Polygon -13840069 true false 165 210 165 255 225 225 165 195 165 255
Polygon -13840069 true false 135 135 135 180 195 150 135 120 135 180
Polygon -13840069 true false 30 105 75 105 45 165 15 105 75 105
Polygon -13840069 true false 135 75 135 30 75 60 135 90 135 30
Polygon -13840069 true false 75 180 120 180 90 240 60 180 120 180
Polygon -13840069 true false 180 105 225 105 195 45 165 105 225 105
Polygon -13840069 true false 240 285 285 285 255 225 225 285 285 285
Polygon -13840069 true false 225 120 270 120 240 180 210 120 270 120
Polygon -13840069 true false 225 30 225 75 285 45 225 15 225 75
Polygon -13840069 true false 120 150 105 120 75 150 120 165 120 105
Polygon -13840069 true false 270 60 240 75 270 105 285 60 225 60
Polygon -13840069 true false 15 225 30 195 60 225 15 240 15 180
Polygon -13840069 true false 60 30 75 0 105 30 60 45 60 -15
Polygon -13840069 true false 150 30 165 60 195 30 150 15 150 75
Polygon -13840069 true false 90 120 105 105 90 90 75 120 135 120
Polygon -13840069 true false 195 180 180 165 165 180 195 195 195 135
Polygon -13840069 true false 225 180 240 195 225 210 210 180 270 180
Polygon -13840069 true false 210 255 225 270 210 285 195 255 255 255
Polygon -13840069 true false 75 270 90 255 105 270 75 285 75 225
Polygon -13840069 true false 15 180 30 165 15 150 0 180 60 180
Polygon -13840069 true false 265 22 280 37 295 22 265 7 265 67
Polygon -13840069 true false 269 201 284 216 269 231 254 201 314 201
Polygon -13840069 true false 143 250 98 250 128 190 158 250 98 250
Polygon -13840069 true false 173 271 158 256 143 271 173 286 173 226
Polygon -13840069 true false 54 265 69 250 54 235 39 265 99 265
Polygon -13840069 true false 0 285 15 255 45 300 0 300 0 285
Polygon -13840069 true false 300 105 270 150 300 150 300 105
Polygon -13840069 true false 105 0 120 15 135 15 150 0 105 0
Polygon -13840069 true false 300 165 270 180 270 195 300 210 300 165
Polygon -13840069 true false 15 0 15 15 0 30 0 0 15 0
Polygon -13840069 true false 180 0 195 15 225 0 180 0
Polygon -13840069 true false 120 270 90 300 135 300 120 270
Polygon -13840069 true false 180 285 195 300 180 300 180 285
Polygon -13840069 true false 300 240 285 255 300 270 300 240
Polygon -13840069 true false 0 135 15 120 0 120 0 135

tile stones original
false
0
Rectangle -6459832 true false 0 0 300 300
Polygon -7500403 true true 0 240 45 195 75 180 90 165 90 135 45 120 0 135
Polygon -7500403 true true 300 240 285 210 270 180 270 150 300 135 300 225
Polygon -7500403 true true 225 300 240 270 270 255 285 255 300 285 300 300
Polygon -7500403 true true 0 285 30 300 0 300
Polygon -7500403 true true 225 0 210 15 210 30 255 60 285 45 300 30 300 0
Polygon -7500403 true true 0 30 30 0 0 0
Polygon -7500403 true true 15 30 75 0 180 0 195 30 225 60 210 90 135 60 45 60
Polygon -7500403 true true 0 105 30 105 75 120 105 105 90 75 45 75 0 60
Polygon -7500403 true true 300 60 240 75 255 105 285 120 300 105
Polygon -7500403 true true 120 75 120 105 105 135 105 165 165 150 240 150 255 135 240 105 210 105 180 90 150 75
Polygon -7500403 true true 75 300 135 285 195 300
Polygon -7500403 true true 30 285 75 285 120 270 150 270 150 210 90 195 60 210 15 255
Polygon -7500403 true true 180 285 240 255 255 225 255 195 240 165 195 165 150 165 135 195 165 210 165 255

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

tree pine
false
0
Rectangle -6459832 true false 120 225 180 300
Polygon -7500403 true true 150 240 240 270 150 135 60 270
Polygon -7500403 true true 150 75 75 210 150 195 225 210
Polygon -7500403 true true 150 7 90 157 150 142 210 157 150 7

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
